@@ -332,7 +332,7 @@ ggsurvplot_core <- function(fit, data = NULL, fun = NULL,
   plots <- x
   grobs <- widths <- list()
   for (i in 1:length(plots)) {
-    if(is.ggplot(plots[[i]])){
+    if(ggplot2::is_ggplot(plots[[i]])){
       grobs[[i]] <- ggplotGrob(plots[[i]])
       # Find panel columns dynamically instead of hardcoding [2:5]
       panel_cols <- which(grepl("panel", grobs[[i]]$layout$name))
@@ -435,12 +435,12 @@ ggsurvplot_core <- function(fit, data = NULL, fun = NULL,
         h_line_data <- data.frame(x = 0, y = max(df$y2), xend = max(df$x1), yend = max(df$y2))
         p <- p +
           geom_segment(aes(x = .data$x, y = .data$y, xend = .data$xend, yend = .data$yend),
-                       data = h_line_data, linetype = linetype, size = size, color = color) # horizontal segment
+                       data = h_line_data, linetype = linetype, linewidth = size, color = color) # horizontal segment
       }
 
       if(type %in% c("hv", "v"))
         p <- p + geom_segment(aes(x = .data$x1, y = .data$y1, xend = .data$x2, yend = .data$y2), data = df,
-                              linetype = linetype, size = size, color = color) # vertical segments
+                              linetype = linetype, linewidth = size, color = color) # vertical segments
     }
     else warning("Median survival not reached.")
   }
