@@ -8,7 +8,6 @@
 #' @importFrom purrr map
 #' @importFrom methods is
 #' @importFrom stats pchisq
-#' @importFrom survMisc ten comp
 #' @importFrom utils capture.output
 #' @importFrom rlang !! sym
 
@@ -25,7 +24,7 @@ is_pkg_version_sup<- function(pkg, version){
 .count_ggplots <- function(list.objects){
   nplot <- 0
   for(i in 1:length(list.objects)){
-    if(is.ggplot(list.objects[[i]])) nplot <- nplot +1
+    if(ggplot2::is_ggplot(list.objects[[i]])) nplot <- nplot +1
   }
   nplot
 }
@@ -64,7 +63,9 @@ GeomConfint <- ggplot2::ggproto('GeomConfint', ggplot2::GeomRibbon,
                                   if (na.rm) data <- data[stats::complete.cases(self$required_aes), ]
                                   data <- data[order(data$group, data$x), ]
                                   data <- self$stairstep_confint(data)
-                                  ggplot2:::GeomRibbon$draw_group(data, panel_scales, coord, na.rm = na.rm)
+                                  if (!is.null(data$linewidth)) data$linewidth <- data$linewidth[1]
+                                  if (!is.null(data$linetype)) data$linetype <- data$linetype[1]
+                                  ggplot2::GeomRibbon$draw_group(data, panel_scales, coord, na.rm = na.rm)
                                 },
                                 stairstep_confint = function (data) {
                                   data <- as.data.frame(data)[order(data$x), ]
@@ -90,7 +91,7 @@ GeomConfint_old <- ggplot2::ggproto('GeomConfint_old', ggplot2::GeomRibbon,
 #                                   if (na.rm) data <- data[stats::complete.cases(self$required_aes), ]
 #                                   data <- data[order(data$group, data$x), ]
 #                                   data <- self$stairstep_confint(data)
-#                                   ggplot2:::GeomRibbon$draw_group(data, panel_scales, coord, na.rm = FALSE)
+#                                   ggplot2::GeomRibbon$draw_group(data, panel_scales, coord, na.rm = FALSE)
 #                                 },
 #                                 stairstep_confint = function (data) {
 #                                   data <- as.data.frame(data)[order(data$x), ]
